@@ -188,9 +188,9 @@ class Connection(object):
         """Hive does not support transactions, so this does nothing."""
         pass
 
-    def cursor(self, *args, **kwargs):
+    def cursor(self, db_name=None):
         """Return a new :py:class:`Cursor` object using the connection."""
-        return Cursor(self, *args, **kwargs)
+        return Cursor(self, database=db_name)
 
     def rollback(self):
         raise Exception("e6xdb does not support transactions")  # pragma: no cover
@@ -208,7 +208,7 @@ class Cursor(DBAPICursor):
     """
     rows_count = 0
 
-    def __init__(self, connection, arraysize=1000):
+    def __init__(self, connection, arraysize=1000, database=None):
         super(Cursor, self).__init__()
         self._arraysize = arraysize
         self.connection = connection
@@ -219,7 +219,7 @@ class Cursor(DBAPICursor):
         self._query_id = None
         self._batch = list()
         self._rowcount = 0
-        self._database = self.connection.database
+        self._database = self.connection.database if database is None else database
 
     def _reset_state(self):
         """Reset state about the previous query in preparation for running another query"""
@@ -497,5 +497,3 @@ if __name__ == '__main__':
 #     # cursor.close()
 #
 #     e6x_connection.close()
-
-
